django_auto_healthchecks package
================================

Module contents
---------------

.. automodule:: django_auto_healthchecks
    :members:
    :undoc-members:
    :exclude-members: Healthcheck

django_auto_healthchecks.healthchecks class
-------------------------------------------

.. automodule:: django_auto_healthchecks.healthchecks
    :members:
    :undoc-members:
    :exclude-members: IdempotentHealthcheckClient,HealthcheckUrl,put,url,HealthcheckError

django_auto_healthchecks.apps module
------------------------------------

.. automodule:: django_auto_healthchecks.apps
    :members:
    :undoc-members:

